# -*- coding: utf-8 -*-

"""Normalise a grid-mapfile
"""

import argparse
import re
import sys

from . import __version__


def create_parser():
    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
        prog="normalize_grid-mapfile",
        usage="cat {grid-mapfile} | %(prog)s > {output}",
    )
    parser.add_argument(
        "-V",
        "--version",
        action="version",
        version=__version__,
    )
    return parser


def main(argv=None):
    """
    """
    # enable a command-line for --help
    parser = create_parser()
    parser.parse_args()

    return normalize(sys.stdin, sys.stdout)


def normalize(infile, outfile):
    mappings = {}
    errors = False
    for number, line in enumerate(infile):
        m = re.search(r"^\s*#+", line.strip())
        if m:
            continue

        m = re.search(r'^"(.+)"\s+(.+)$', line.strip())
        if not m:
            print(
                "Error parsing line %d: %s" % (number + 1, line.strip()),
                file=sys.stderr,
            )
            errors = True
            continue

        subject = m.group(1)
        login_string = m.group(2)
        logins = login_string.split(",")

        if subject in mappings:
            mappings[subject].extend(logins)
        else:
            mappings[subject] = logins

    if errors:
        sys.exit(1)

    subjects = sorted(mappings.keys())

    for s in subjects:
        logins = mappings[s]
        logins.sort()
        login_string = ",".join(logins)

        print('"%s" %s' % (s, login_string))


if __name__ == "__main__":
    sys.exit(main(sys.argv))
