import os
import sys
import unittest
import logging
from pathlib import Path

import lgmm

from .mock_ldap import MockLIGOLDAP

logging.basicConfig(
    level=eval("logging." + os.environ.get("LGMM_LOGLEVEL", "CRITICAL"))
)
logger = logging.getLogger("lgmm")


def _find_lgmm_config(filename="lgmm_config.py"):
    _config_locs = (
        Path("etc"),  # local copy
        Path(sys.prefix) / "etc" / "lgmm",  # packaged copy
        Path("/etc") / "lgmm",  # system copy
    )
    # attempt to find in a sensible location
    for _loc in _config_locs:
        _conf = _loc / filename
        if _conf.is_file():
            return str(_conf)
    raise RuntimeError(
        "cannot find {} in any known location".format(filename),
    )


LGMM_CONFIG = _find_lgmm_config()


def as_list(obj):
    return obj if isinstance(obj, list) else [obj]


class TestCase(unittest.TestCase):
    def assertRegex(self, a, b):
        if sys.version_info >= (3, 2):
            return super(TestCase, self).assertRegex(a, b)
        else:
            return self.assertRegexpMatches(a, b)


class MockLIGOLDAPWithManager(MockLIGOLDAP):
    def setUp(self):
        super(MockLIGOLDAPWithManager, self).setUp()
        self.manager = lgmm.MapfileManager(
            ["lgmm", "--config", LGMM_CONFIG], logger=logger
        )
